<?php

/*
 * LMS version 1.4-cvs
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: postgres.2004090700.php,v 1.6 2007/01/07 08:10:03 alec Exp $
 */

$DB->BeginTrans();
$DB->Execute("
    CREATE INDEX cash_userid_idx ON cash(userid);
    UPDATE dbinfo SET keyvalue = '2004090700' WHERE keytype = 'dbversion';
");
$DB->CommitTrans();

?>
